@@ -59,6 +59,8 @@ departments = {
             "Don Matías":{"dane_code":"05237"},
             "Ebéjico":{"dane_code":"05240"},
             "El Bagre":{"dane_code":"05250"},
+            "Carmen de Viboral":{"dane_code":"05148"},
+            "El Carmen":{"dane_code":"05148"},
             "Entrerrios":{"dane_code":"05264"},
             "Envigado":{"dane_code":"05266"},
             "Fredonia":{"dane_code":"05282"},
@@ -183,17 +185,20 @@ departments = {
     "Bolívar": {
         "dane_code":"13",
         "municipalities":{
-            "El Peñón":{"dane_code":"13268"},
             "Achí":{"dane_code":"13006"},
             "Arenal":{"dane_code":"13042"},
             "Arjona":{"dane_code":"13052"},
             "Arroyohondo":{"dane_code":"13062"},
             "Calamar":{"dane_code":"13140"},
             "Cantagallo":{"dane_code":"13160"},
+            "Carmen De Bolívar":{"dane_code":"13244"},
             "Cicuco":{"dane_code":"13188"},
             "Córdoba":{"dane_code":"13212"},
             "Clemencia":{"dane_code":"13222"},
             "El Guamo":{"dane_code":"13248"},
+            "El Guamo":{"dane_code":"13248"},
+            "El Peñón":{"dane_code":"13268"},
+            "Hatillo de Loba":{"dane_code":"13300"},
             "Magangué":{"dane_code":"13430"},
             "Mahates":{"dane_code":"13433"},
             "Margarita":{"dane_code":"13440"},
@@ -217,12 +222,12 @@ departments = {
             "Turbaná":{"dane_code":"13838"},
             "Villanueva":{"dane_code":"13873"},
             "Cartagena":{"dane_code":"13001"},
+            "Cartagena de indias":{"dane_code":"13001"},
             "María la Baja":{"dane_code":"13442"},
             "San Cristóbal":{"dane_code":"13620"},
             "Zambrano":{"dane_code":"13894"},
             "Barranco de Loba":{"dane_code":"13074"},
             "Santa Rosa del Sur":{"dane_code":"13688"},
-            "Hatillo de Loba":{"dane_code":"13300"},
         }
     },
     "Boyacá": {
@@ -533,6 +538,7 @@ departments = {
             "Istmina":{"dane_code":"27361"},
             "El Litoral del San Juan":{"dane_code":"27250"},
             "El Cantón del San Pablo":{"dane_code":"27135"},
+            "El Carmen De Atrato":{"dane_code":"27245"},
         }
     },
     "Córdoba":{
@@ -677,6 +683,7 @@ departments = {
             "Topaipí":{"dane_code":"25823"},
             "Ubalá":{"dane_code":"25839"},
             "Ubaque":{"dane_code":"25841"},
+            "Ubate":{"dane_code":"25843"},
             "Une":{"dane_code":"25845"},
             "Útica":{"dane_code":"25851"},
             "Vianí":{"dane_code":"25867"},
@@ -915,6 +922,7 @@ departments = {
             "Cúcuta":{"dane_code":"54001"},
             "El Carmen":{"dane_code":"54245"},
             "los patios":{"dane_code":"54405"},
+            "Ocaña":{"dane_code":"54498"},
         }
     },
     "Putumayo":{
@@ -925,6 +933,7 @@ departments = {
             "Mocoa":{"dane_code":"86001"},
             "Colón":{"dane_code":"86219"},
             "Orito":{"dane_code":"86320"},
+            "Puerto Asis":{"dane_code":"86568"},
             "Puerto Caicedo":{"dane_code":"86569"},
             "Puerto Guzmán":{"dane_code":"86571"},
             "Leguízamo":{"dane_code":"86573"},
@@ -1081,6 +1090,7 @@ departments = {
             "San Onofre":{"dane_code":"70713"},
             "San Pedro":{"dane_code":"70717"},
             "Sucre":{"dane_code":"70771"},
+            "Sincé":{"dane_code":"70742"},
             "Tolú Viejo":{"dane_code":"70823"},
             "San Luis de Sincé":{"dane_code":"70742"},
         }
